import {select,csv} from 'd3'
csv('data.csv') .then(data=>{
  console.log(data);
});

// Set the dimensions of the chart
const margin = { top: 20, right: 20, bottom: 60, left: 60 },
  width = 600 - margin.left - margin.right,
  height = 400 - margin.top - margin.bottom;

// Append the svg object to the body of the page
const svg = d3
  .select(".chart")
  .append("svg")
  .attr("width", width + margin.left + margin.right)
  .attr("height", height + margin.top + margin.bottom)
  .append("g")
  .attr("transform", "translate(" + margin.left + "," + margin.top + ")");

// Set the scales and axis
const xScale = d3.scaleLinear().range([0, width]);
const yScale = d3.scaleLinear().range([height, 0]);
const xAxis = d3.axisBottom().scale(xScale);
const yAxis = d3.axisLeft().scale(yScale);

// Set the tooltip
const tooltip = d3
  .select(".chart")
  .append("div")
  .attr("class", "tooltip")
  .style("opacity", 0);

// Define the update function
function update(data, xAttribute, yAttribute) {
  // Set the domains
  xScale.domain(d3.extent(data, (d) => d[xAttribute])).nice();
  yScale.domain(d3.extent(data, (d) => d[yAttribute])).nice();

  svg
  .append("g")
  .attr("class", "x-axis")
  .attr("transform", "translate(0," + height + ")")
  .call(xAxis)
  .append("text")
  .attr("class", "axis-label")
  .attr("x", width)
  .attr("y", -6)
  .style("text-anchor", "end")
  .text("Sepal_Length");

  // Add y-axis label
svg.append("text")
  .attr("class", "y-label")
  .attr("transform", "rotate(-90)")
  .attr("x", -height / 2)
  .attr("y", -margin.left + 20)
  .attr("text-anchor", "middle")
  .text("Sepal_width");

  svg
    .append("g")
    .attr("class", "y-axis")
    .call(yAxis)
    .append("text")
    .attr("class", "axis-label")
    .attr("transform", "rotate(-90)")
    .attr("y", 6)
    .attr("dy", ".71em")
    .style("text-anchor", "end")
    .text(yAttribute);

  // Add the data points
  const circles = svg.selectAll("circle").data(data);

  circles
    .enter()
    .append("circle")
    .merge(circles)
    .attr("cx", (d) => xScale(d[xAttribute]))
    .attr("cy", (d) => yScale(d[yAttribute]))
    .attr("r", 5)
    .attr("fill", "steelblue")
    .on("mouseover", function (d) {
      tooltip
      .transition()
.duration(200)
.style("opacity", 0.9);
tooltip
.html(
"<strong>" +
d.species +
"</strong><br/>" +
xAttribute +
": " +
d[xAttribute] +
"<br/>" +
yAttribute +
": " +
d[yAttribute]
)
.style("left", d3.event.pageX + "px")
.style("top", d3.event.pageY - 28 + "px");
})
.on("mouseout", function (d) {
tooltip.transition().duration(500).style("opacity", 0);
});

circles.exit().remove();
}

// Load the data and call the update function
d3.csv("data.csv").then((data) => {
data.forEach((d) => {
d.sepal_length = +d.sepal_length;
d.sepal_width = +d.sepal_width;
d.petal_length = +d.petal_length;
d.petal_width = +d.petal_width;
});

update(data, "sepal_length", "sepal_width");
});

// Add event listeners to the buttons
document.getElementById("sepal-length-sepal-width").addEventListener("click", () => {
d3.csv("data.csv").then((data) => {
update(data, "sepal_length", "sepal_width");
});
});

document.getElementById("sepal-length-petal-length").addEventListener("click", () => {
d3.csv("data.csv").then((data) => {
update(data, "sepal_length", "petal_length");
});
});

document.getElementById("sepal-width-petal-length").addEventListener("click", () => {
d3.csv("data.csv").then((data) => {
update(data, "sepal_width", "petal_length");
});
});
